@@ -13,12 +13,13 @@ my $ua = Test::WWW::Mechanize::PSGI->new(
         return [
             200,
             [ 'Content-Type' => 'text/html' ],
-            [   '<html><head><title>Hi</title></head><body>Hello World</body></html>'
+            [
+                '<html><head><title>Hi</title></head><body>Hello World</body></html>'
             ]
         ];
     },
 );
-my $logger = debug_ua( $ua );
+my $logger = debug_ua($ua);
 
 # Test::WWW::Mechanize::PSGI overrides LWP::UserAgent::simple_request(), which
 # is what would normally call LWP::UserAgent::send_request().  So, the default
@@ -28,9 +29,11 @@ my $logger = debug_ua( $ua );
 # LWP::UserAgent::prepare_request().  That's earlier on in the request phase,
 # but still helpful.
 
-$ua->add_handler( 'request_prepare',
-    sub { $logger->request_callback( @_ ) } );
+$ua->add_handler(
+    'request_prepare',
+    sub { $logger->request_callback(@_) }
+);
 
-$ua->get_ok( '/' );
+$ua->get_ok('/');
 
 done_testing();
